@@ -63,7 +63,6 @@ use core::fmt::{self, Binary, Debug, Display, Formatter, LowerHex, Octal, UpperH
 use core::marker::PhantomData;
 use core::num::TryFromIntError;
 
-use byteorder::ByteOrder;
 use zerocopy_derive::*;
 
 use crate::AsBytes;
@@ -71,6 +70,11 @@ use crate::AsBytes;
 // explanation.
 use crate::zerocopy;
 
+// NOTE: We don't reexport `WriteBytesExt` or `ReadBytesExt` because those are
+// only available with the `std` feature enabled, and zerocopy is `no_std` by
+// default.
+pub use byteorder::{BigEndian, ByteOrder, LittleEndian, NativeEndian, NetworkEndian, BE, LE};
+
 macro_rules! impl_fmt_trait {
     ($name:ident, $native:ident, $trait:ident) => {
         impl<O: ByteOrder> $trait for $name<O> {
